@@ -48,12 +48,8 @@ func breakdownCmd(ctx *config.RunContext) *cobra.Command {
 
 	cmd.Flags().String("out-file", "", "Save output to a file, helpful with format flag")
 	cmd.Flags().Bool("terraform-use-state", false, "Use Terraform state instead of generating a plan. Applicable when path is a Terraform directory")
-	cmd.Flags().String("format", "table", "Output format: json, table, html")
+	newEnumFlag(cmd, "format", "table", "Output format", []string{"json", "table", "html"})
 	cmd.Flags().StringSlice("fields", []string{"monthlyQuantity", "unit", "monthlyCost"}, "Comma separated list of output fields: all,price,monthlyQuantity,unit,hourlyCost,monthlyCost.\nSupported by table and html output formats")
 
-	_ = cmd.RegisterFlagCompletionFunc("format", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
-		return validRunFormats, cobra.ShellCompDirectiveDefault
-	})
-
 	return cmd
 }
