@@ -15,6 +15,7 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/zclconf/go-cty/cty"
 
+	"github.com/infracost/infracost/internal/extclient"
 	"github.com/infracost/infracost/internal/hcl/modules"
 	"github.com/infracost/infracost/internal/ui"
 )
@@ -51,21 +52,82 @@ func OptionStopOnHCLError() Option {
 	}
 }
 
-// OptionWithInputVars takes a cmd line var input values and converts them to cty.Value
-// It then sets these as the Parser starting inputVars which be used at the root module evaluation.
-func OptionWithInputVars(vs []string) Option {
+// OptionWithTFEnvVars takes any TF_ENV_xxx=yyy from the environment and converts them to cty.Value
+// It then sets these as the Parser starting tfEnvVars which are used at the root module evaluation.
+func OptionWithTFEnvVars(projectEnv map[string]string) Option {
 	return func(p *Parser) {
 		ctyVars := make(map[string]cty.Value)
+
+		// First load any TF_VARs set in the environment
+		for _, v := range os.Environ() {
+			if strings.HasPrefix(v, "TF_VAR_") {
+				pieces := strings.Split(v[len("TF_VAR_"):], "=")
+				if len(pieces) != 2 {
+					continue
+				}
+
+				ctyVars[pieces[0]] = cty.StringVal(pieces[1])
+			}
+		}
+
+		// Then load any TF_VARs set in the project config "env:" block
+		for k, v := range projectEnv {
+			if strings.HasPrefix(k, "TF_VAR_") {
+				ctyVars[k[len("TF_VAR_"):]] = cty.StringVal(v)
+			}
+		}
+
+		p.tfEnvVars = ctyVars
+	}
+}
+
+// OptionWithPlanFlagVars takes TF var inputs specified in a command line string and converts them to cty.Value
+// It sets these as the Parser starting inputVars which are used at the root module evaluation.
+func OptionWithPlanFlagVars(vs []string) Option {
+	return func(p *Parser) {
+		if p.inputVars == nil {
+			p.inputVars = make(map[string]cty.Value)
+		}
 		for _, v := range vs {
 			pieces := strings.Split(v, "=")
 			if len(pieces) != 2 {
 				continue
 			}
 
-			ctyVars[pieces[0]] = cty.StringVal(pieces[1])
+			p.inputVars[pieces[0]] = cty.StringVal(pieces[1])
+		}
+	}
+}
+
+// OptionWithInputVars takes cmd line var input values and converts them to cty.Value
+// It sets these as the Parser starting inputVars which are used at the root module evaluation.
+func OptionWithInputVars(vars map[string]string) Option {
+	return func(p *Parser) {
+		if p.inputVars == nil {
+			p.inputVars = make(map[string]cty.Value, len(vars))
 		}
 
-		p.inputVars = ctyVars
+		for k, v := range vars {
+			p.inputVars[k] = cty.StringVal(v)
+		}
+	}
+}
+
+// OptionWithRemoteVarLoader accepts Terraform Cloud/Enterprise host and token
+// values to load remote execution variables.
+func OptionWithRemoteVarLoader(host, token, localWorkspace string) Option {
+	return func(p *Parser) {
+		if host == "" || token == "" {
+			return
+		}
+
+		var loaderOpts []RemoteVariablesLoaderOption
+		if p.newSpinner != nil {
+			loaderOpts = append(loaderOpts, RemoteVariablesLoaderWithSpinner(p.newSpinner))
+		}
+
+		client := extclient.NewAuthedAPIClient(host, token)
+		p.remoteVariablesLoader = NewRemoteVariablesLoader(client, localWorkspace, loaderOpts...)
 	}
 }
 
@@ -101,16 +163,18 @@ func OptionWithWarningFunc(f ui.WriteWarningFunc) Option {
 
 // Parser is a tool for parsing terraform templates at a given file system location.
 type Parser struct {
-	initialPath     string
-	defaultVarFiles []string
-	tfvarsPaths     []string
-	inputVars       map[string]cty.Value
-	stopOnHCLError  bool
-	workspaceName   string
-	moduleLoader    *modules.ModuleLoader
-	blockBuilder    BlockBuilder
-	newSpinner      ui.SpinnerFunc
-	writeWarning    ui.WriteWarningFunc
+	initialPath           string
+	tfEnvVars             map[string]cty.Value
+	defaultVarFiles       []string
+	tfvarsPaths           []string
+	inputVars             map[string]cty.Value
+	stopOnHCLError        bool
+	workspaceName         string
+	moduleLoader          *modules.ModuleLoader
+	blockBuilder          BlockBuilder
+	newSpinner            ui.SpinnerFunc
+	writeWarning          ui.WriteWarningFunc
+	remoteVariablesLoader *RemoteVariablesLoader
 }
 
 // New creates a new Parser with the provided options, it inits the workspace as under the default name
@@ -179,11 +243,11 @@ func (p *Parser) ParseDirectory() (*Module, error) {
 	}
 
 	if len(blocks) == 0 {
-		return nil, errors.New("Error no valid tf files found in given path")
+		return nil, errors.New("No valid terraform files found given path, try a different directory")
 	}
 
 	log.Debug("Loading TFVars...")
-	inputVars, err := p.loadVars(p.tfvarsPaths)
+	inputVars, err := p.loadVars(blocks, p.tfvarsPaths)
 	if err != nil {
 		return nil, err
 	}
@@ -267,8 +331,24 @@ func (p *Parser) parseDirectoryFiles(files []*hcl.File) (Blocks, error) {
 	return blocks, nil
 }
 
-func (p *Parser) loadVars(filenames []string) (map[string]cty.Value, error) {
-	combinedVars := make(map[string]cty.Value)
+func (p *Parser) loadVars(blocks Blocks, filenames []string) (map[string]cty.Value, error) {
+	combinedVars := p.tfEnvVars
+	if combinedVars == nil {
+		combinedVars = make(map[string]cty.Value)
+	}
+
+	if p.remoteVariablesLoader != nil {
+		remoteVars, err := p.remoteVariablesLoader.Load(blocks)
+
+		if err != nil {
+			log.Warnf("could not load vars from Terraform Cloud: %s", err)
+			return combinedVars, err
+		}
+
+		for k, v := range remoteVars {
+			combinedVars[k] = v
+		}
+	}
 
 	for _, name := range p.defaultVarFiles {
 		err := loadAndCombineVars(name, combinedVars)
