@@ -27,27 +27,28 @@ import (
 var minTerraformVer = "v0.12"
 
 type DirProvider struct {
-	ctx                 *config.ProjectContext
-	Path                string
-	spinnerOpts         ui.SpinnerOptions
-	IsTerragrunt        bool
-	PlanFlags           string
-	InitFlags           string
-	Workspace           string
-	UseState            bool
-	TerraformBinary     string
-	TerraformCloudHost  string
-	TerraformCloudToken string
-	Env                 map[string]string
-	cachedStateJSON     []byte
-	cachedPlanJSON      []byte
+	ctx                  *config.ProjectContext
+	Path                 string
+	spinnerOpts          ui.SpinnerOptions
+	IsTerragrunt         bool
+	PlanFlags            string
+	InitFlags            string
+	Workspace            string
+	UseState             bool
+	TerraformBinary      string
+	TerraformCloudHost   string
+	TerraformCloudToken  string
+	Env                  map[string]string
+	cachedStateJSON      []byte
+	cachedPlanJSON       []byte
+	includePastResources bool
 }
 
 type RunShowOptions struct {
 	CmdOptions *CmdOptions
 }
 
-func NewDirProvider(ctx *config.ProjectContext) schema.Provider {
+func NewDirProvider(ctx *config.ProjectContext, includePastResources bool) schema.Provider {
 	terraformBinary := ctx.ProjectConfig.TerraformBinary
 	if terraformBinary == "" {
 		terraformBinary = defaultTerraformBinary
@@ -61,14 +62,15 @@ func NewDirProvider(ctx *config.ProjectContext) schema.Provider {
 			NoColor:       ctx.RunContext.Config.NoColor,
 			Indent:        "  ",
 		},
-		PlanFlags:           ctx.ProjectConfig.TerraformPlanFlags,
-		InitFlags:           ctx.ProjectConfig.TerraformInitFlags,
-		Workspace:           ctx.ProjectConfig.TerraformWorkspace,
-		UseState:            ctx.ProjectConfig.TerraformUseState,
-		TerraformBinary:     terraformBinary,
-		TerraformCloudHost:  ctx.ProjectConfig.TerraformCloudHost,
-		TerraformCloudToken: ctx.ProjectConfig.TerraformCloudToken,
-		Env:                 ctx.ProjectConfig.Env,
+		PlanFlags:            ctx.ProjectConfig.TerraformPlanFlags,
+		InitFlags:            ctx.ProjectConfig.TerraformInitFlags,
+		Workspace:            ctx.ProjectConfig.TerraformWorkspace,
+		UseState:             ctx.ProjectConfig.TerraformUseState,
+		TerraformBinary:      terraformBinary,
+		TerraformCloudHost:   ctx.ProjectConfig.TerraformCloudHost,
+		TerraformCloudToken:  ctx.ProjectConfig.TerraformCloudToken,
+		Env:                  ctx.ProjectConfig.Env,
+		includePastResources: includePastResources,
 	}
 }
 
@@ -163,7 +165,7 @@ func (p *DirProvider) LoadResources(usage map[string]*schema.UsageData) ([]*sche
 
 		project := schema.NewProject(name, metadata)
 
-		parser := NewParser(p.ctx)
+		parser := NewParser(p.ctx, p.includePastResources)
 		pastResources, resources, err := parser.parseJSON(j, usage)
 		if err != nil {
 			return projects, errors.Wrap(err, "Error parsing Terraform JSON")
