@@ -8,20 +8,25 @@ import (
 func getComputeAddressRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:                "google_compute_address",
-		RFunc:               NewComputeAddress,
+		RFunc:               newComputeAddress,
 		ReferenceAttributes: []string{},
 	}
 }
-func GetComputeGlobalAddressRegistryItem() *schema.RegistryItem {
+func getComputeGlobalAddressRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:                "google_compute_global_address",
-		RFunc:               NewComputeAddress,
+		RFunc:               newComputeAddress,
 		ReferenceAttributes: []string{},
 	}
 }
 
-func NewComputeAddress(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	r := &google.ComputeAddress{Address: d.Address, Region: d.Get("region").String(), AddressType: d.Get("address_type").String()}
+func newComputeAddress(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+	r := &google.ComputeAddress{
+		Address:     d.Address,
+		Region:      d.Get("region").String(),
+		AddressType: d.Get("address_type").String(),
+	}
 	r.PopulateUsage(u)
+
 	return r.BuildResource()
 }
