@@ -7,10 +7,12 @@ import (
 )
 
 func TestComputeAddress(t *testing.T) {
-	t.Parallel()
 	if testing.Short() {
 		t.Skip("skipping test in short mode")
 	}
 
-	tftest.GoldenFileResourceTests(t, "compute_address_test")
+	opts := tftest.DefaultGoldenFileOptions()
+	opts.CaptureLogs = true
+
+	tftest.GoldenFileResourceTestsWithOpts(t, "compute_address_test", opts)
 }
