@@ -57,6 +57,28 @@ func varsFromPlanFlags(planFlags string) (vars, error) {
 	}, nil
 }
 
+func findRemoteHostAndToken(ctx *config.ProjectContext) (string, string, error) {
+	token := ctx.ProjectConfig.TerraformCloudToken
+
+	if token == "" && !checkCloudConfigSet() {
+		return "", "", ErrMissingCloudToken
+	}
+
+	host := ctx.ProjectConfig.TerraformCloudHost
+	if host == "" {
+		host = "app.terraform.io"
+	}
+
+	if token == "" {
+		token = findCloudToken(host)
+	}
+	if token == "" {
+		return "", "", ErrMissingCloudToken
+	}
+
+	return host, token, nil
+}
+
 // NewHCLProvider returns a HCLProvider with a hcl.Parser initialised using the config.ProjectContext.
 // It will use input flags from either the terraform-plan-flags or top level var and var-file flags to
 // set input vars and files on the underlying hcl.Parser.
@@ -66,20 +88,32 @@ func NewHCLProvider(ctx *config.ProjectContext, provider *PlanJSONProvider, opts
 		return nil, fmt.Errorf("could not parse vars from plan flags %w", err)
 	}
 
-	var options []hcl.Option
+	options := []hcl.Option{hcl.OptionWithTFEnvVars(ctx.ProjectConfig.Env)}
+
+	if len(v.vars) > 0 {
+		withPlanFlagVars := hcl.OptionWithPlanFlagVars(v.vars)
+		options = append(options, withPlanFlagVars)
+	}
+
 	v.files = append(v.files, ctx.ProjectConfig.TerraformVarFiles...)
 	if len(v.files) > 0 {
 		withFiles := hcl.OptionWithTFVarsPaths(v.files)
 		options = append(options, withFiles)
 	}
 
-	v.vars = append(v.vars, ctx.ProjectConfig.TerraformVars...)
-	if len(v.vars) > 0 {
-		withVars := hcl.OptionWithInputVars(v.vars)
-		options = append(options, withVars)
+	if len(ctx.ProjectConfig.TerraformVars) > 0 {
+		withInputVars := hcl.OptionWithInputVars(ctx.ProjectConfig.TerraformVars)
+		options = append(options, withInputVars)
 	}
 
 	options = append(options, opts...)
+
+	host, token, remErr := findRemoteHostAndToken(ctx)
+	localWorkspace := ctx.ProjectConfig.TerraformWorkspace
+	if remErr == nil {
+		options = append(options, hcl.OptionWithRemoteVarLoader(host, token, localWorkspace))
+	}
+
 	p := hcl.New(ctx.ProjectConfig.Path, options...)
 
 	return &HCLProvider{
