@@ -3,11 +3,12 @@ package terraform
 import (
 	"testing"
 
-	"github.com/infracost/infracost/internal/config"
-	"github.com/infracost/infracost/internal/schema"
 	"github.com/shopspring/decimal"
 	"github.com/stretchr/testify/assert"
 	"github.com/tidwall/gjson"
+
+	"github.com/infracost/infracost/internal/config"
+	"github.com/infracost/infracost/internal/schema"
 )
 
 func TestParseJSONResources(t *testing.T) {
@@ -276,7 +277,7 @@ func TestParseJSONResources(t *testing.T) {
 	conf := parsed.Get("configuration.root_module")
 	vars := parsed.Get("variables")
 
-	p := NewParser(config.EmptyProjectContext())
+	p := NewParser(config.EmptyProjectContext(), true)
 
 	actual := p.parseJSONResources(false, nil, usage, parsed, providerConf, conf, vars)
 
@@ -344,7 +345,7 @@ func TestCreateResource(t *testing.T) {
 		},
 	}
 
-	p := NewParser(config.EmptyProjectContext())
+	p := NewParser(config.EmptyProjectContext(), true)
 
 	for _, test := range tests {
 		actual := p.createResource(test.data, nil)
@@ -523,7 +524,7 @@ func TestParseResourceData(t *testing.T) {
 		"module.module1.aws_nat_gateway.nat2": "eu-west-2",
 	}
 
-	p := NewParser(config.EmptyProjectContext())
+	p := NewParser(config.EmptyProjectContext(), true)
 	actual := p.parseResourceData(false, providerConf, planVals, conf, vars)
 
 	for k, v := range actual {
@@ -592,7 +593,7 @@ func TestParseReferences_plan(t *testing.T) {
 		}`,
 	}
 
-	p := NewParser(config.EmptyProjectContext())
+	p := NewParser(config.EmptyProjectContext(), true)
 	p.parseReferences(resData, conf)
 
 	assert.Equal(t, []*schema.ResourceData{vol1}, resData["aws_ebs_snapshot.snapshot1"].References("volume_id"))
@@ -632,7 +633,7 @@ func TestParseReferences_state(t *testing.T) {
 
 	conf := gjson.Result{}
 
-	p := NewParser(config.EmptyProjectContext())
+	p := NewParser(config.EmptyProjectContext(), true)
 	p.parseReferences(resData, conf)
 
 	assert.Equal(t, []*schema.ResourceData{vol1}, resData["aws_ebs_snapshot.snapshot1"].References("volume_id"))
