@@ -48,6 +48,23 @@ func GetResourceRegistryMap() *ResourceRegistryMap {
 	return &resourceRegistryMap
 }
 
+func (r *ResourceRegistryMap) GetReferenceAttributes(resourceDataType string) []string {
+	var refAttrs []string
+	item, ok := (*r)[resourceDataType]
+	if ok {
+		refAttrs = item.ReferenceAttributes
+	}
+	return refAttrs
+}
+
+func (r *ResourceRegistryMap) GetCustomRefIDFunc(resourceDataType string) schema.ReferenceIDFunc {
+	item, ok := (*r)[resourceDataType]
+	if ok {
+		return item.CustomRefIDFunc
+	}
+	return nil
+}
+
 func GetUsageOnlyResources() []string {
 	r := []string{}
 	r = append(r, aws.UsageOnlyResources...)
